@@ -13,6 +13,8 @@ def runGame(Ais,gameName):
     try:
         if gameName == "Connect4":
             game = AIArena.games.Connect4(players=Ais)
+        elif gameName == "Arena":
+            game = AIArena.games.Arena(players=Ais)
         else:
             result["error"] = "Game Creation: Bad Name"
             return result
